#!/bin/ksh


IFIX_FILENAME=hatsd.ifix

LOCAL_CHECKSUM=$(cksum $IFIX_FILENAME)
if [[ "$LOCAL_CHECKSUM" != "2601870724 2124869 hatsd.ifix" ]]
then
    print "Checksum of delivered file has been compromised."
    print " Current: $LOCAL_CHECKSUM"
    print "Expected: 2601870724 2124869 hatsd.ifix"
    exit 1
fi

if [[ -f hatsd.orig ]]
then
    print "Error: This package appears to have already been installed."
    print "(If manual cleanup or removal is necessary, please contact IBM support.)"
    exit 1
fi


if [[ -d /opt/rsct ]]
then
    RSCT_PATH=/opt/rsct
else
    RSCT_PATH=/usr/sbin/rsct
fi

RSCT_VRMF=$(${RSCT_PATH}/install/bin/ctversion | awk '{print $2}')

RSCT_VER=${RSCT_VRMF%.*}
let RSCT_FIX=${RSCT_VRMF##*.}

if [[ $RSCT_VER != "3.2.0" ]] || (( RSCT_FIX > 13 ))
then
    print "Error: Package not compatible with RSCT ${RSCT_VRMF}"
    exit 1
fi

ARCH=$(uname -p)

if [[ $ARCH != "x86_64" ]]
then
    print "Error: Architecture type \"${ARCH}\" not supported for this fix."
    exit 1
fi

TARGET_FILENAME=${RSCT_PATH}/bin/hatsd

if [[ ! -f $TARGET_FILENAME ]]
then
    print "Could not find target file ${TARGET_FILENAME}"
    ls $TARGET_FILENAME
    exit 1
fi


LSSRC_CONFIGRM=$(lssrc -s IBM.ConfigRM | tail -1)
CONFIGRM_STATE=${LSSRC_CONFIGRM##* }
RPD_ONLINE=$(${RSCT_PATH}/bin/lsrpdomain -xo)

if [[ -n $RPD_ONLINE && $CONFIGRM_STATE != "inoperative" ]]
then
    print "Cannot install while a domain is online:"
    print "$RPD_ONLINE"
    print "(lssrc -s IBM.ConfigRM: $LSSRC_CONFIGRM)"
    exit 1
fi


cp $TARGET_FILENAME hatsd.orig
cp $IFIX_FILENAME $TARGET_FILENAME

print "Install completed"

exit 0

